abacusai.concatenation_config — AbacusAI documentation

# abacusai.concatenation_config

## Classes

`ConcatenationConfig` | Feature Group Concatenation Config

## Module Contents

class abacusai.concatenation_config.ConcatenationConfig(client, concatenatedTable=None, mergeType=None, replaceUntilTimestamp=None, skipMaterialize=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Feature Group Concatenation Config

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - concatenatedTable (str) – The feature group to concatenate with the destination feature group.

    - mergeType (str) – The type of merge to perform, either UNION or INTERSECTION.

    - replaceUntilTimestamp (int) – The Unix timestamp to specify the point up to which data from the source feature group will be replaced.

    - skipMaterialize (bool) – If True, the concatenated feature group will not be materialized.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict